@@ -14,7 +14,7 @@ test_that("with_envvar sets and unsets variables", {
   expect_false("set_env_testvar" %in% names(Sys.getenv()))
 })
 
-test_that("with_envar respects suffix and prefix", {
+test_that("with_envvar respects suffix and prefix", {
   nested <- function(op1, op2) {
     with_envvar(c(A = 1), action = op1,
       with_envvar(c(A = 2), action = op2,
@@ -32,13 +32,13 @@ test_that("with_envar respects suffix and prefix", {
 })
 
 test_that("with_options works", {
-  expect_that(getOption("scipen"), not(equals(999)))
+  expect_false(identical(getOption("scipen"), 999))
   expect_equal(with_options(c(scipen=999), getOption("scipen")), 999)
-  expect_that(getOption("scipen"), not(equals(999)))
+  expect_false(identical(getOption("scipen"), 999))
 
-  expect_that(getOption("zyxxyzyx"), not(equals("qwrbbl")))
+  expect_false(identical(getOption("zyxxyzyx"), "qwrbbl"))
   expect_equal(with_options(c(zyxxyzyx="qwrbbl"), getOption("zyxxyzyx")), "qwrbbl")
-  expect_that(getOption("zyxxyzyx"), not(equals("qwrbbl")))
+  expect_false(identical(getOption("zyxxyzyx"), "qwrbbl"))
 })
 
 test_that("with_libpaths works and resets library", {
@@ -61,6 +61,15 @@ test_that("with_temp_libpaths works and resets library", {
   expect_equal(lib, .libPaths())
 })
 
+test_that("with_temp_libpaths has an action argument", {
+  lib <- .libPaths()
+  with_temp_libpaths(
+    action = "suffix",
+    expect_equal(.libPaths()[-length(.libPaths())], lib)
+  )
+  expect_equal(lib, .libPaths())
+})
+
 test_that("with_ works", {
   res <- NULL
   set <- function(new) {
@@ -88,7 +97,7 @@ test_that("with_ works on functions without arguments", {
 })
 
 test_that("with_path works and resets path", {
-  current <- normalizePath(get_path())
+  current <- normalizePath(get_path(), mustWork = FALSE)
   new_path <- normalizePath(".")
   with_path(
     new_path,
@@ -101,7 +110,7 @@ test_that("with_path works and resets path", {
 })
 
 test_that("with_path with suffix action works and resets path", {
-  current <- normalizePath(get_path())
+  current <- normalizePath(get_path(), mustWork = FALSE)
   new_path <- normalizePath(".")
   with_path(
     new_path,
@@ -115,7 +124,7 @@ test_that("with_path with suffix action works and resets path", {
 })
 
 test_that("with_path with replace action works and resets path", {
-  current <- normalizePath(get_path())
+  current <- normalizePath(get_path(), mustWork = FALSE)
   new_path <- normalizePath(".")
   with_path(
     new_path,
@@ -195,6 +204,19 @@ test_that("with_makevars changes only the defined variables", {
   expect_equal(current, readLines(current_name))
 })
 
+test_that("with_makevars works with alternative assignments", {
+  current <- tempfile()
+  writeLines(con = current, c("CFLAGS=-03"), sep = "\n")
+  new <- c(CFLAGS = "-O0")
+  with_makevars(
+    new, path = current, assignment = "+=",
+    {
+      expect_equal("CFLAGS+=-O0", readLines(Sys.getenv("R_MAKEVARS_USER")))
+    }
+  )
+  expect_equal("CFLAGS=-03", readLines(current))
+})
+
 test_that("set_makevars works as expected", {
   expect_equal(set_makevars(character(0)), NULL)
 
